# Kojis
A module to help kids learn python via fun emojis.

Kojis is created by Pylan & Friends

>Version 1x
>> Kojis added to Pypi

>> Kojis description added to





# Get started with Kojis

>>>As of 7/15/2021 pip install Kojis will only install version 1.1
>>>
>>>The tutorial uses the latest version as of 7/15/2021, 1.3. Please install 1.3 via GitHub

>Hello World but with Kojis...

``import kojis``

 ``print("Hello " + Kojis.faces.earth)``

  
  # Letter from the authors
  
 >The source code for Kojis was created by Pylan and fellow Pypi Contributor TechnoBlade along with an README writer

  ##Release History
  >1.3 GitHub release
  >
  >1.4 in dev 
  
  
  





